@@ -1,7 +1,9 @@
 package Log::ger::Output::File;
 
-our $DATE = '2017-06-23'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-08-02'; # DATE
+our $VERSION = '0.003'; # VERSION
+
+## no critic (InputOutput::RequireBriefOpen)
 
 use strict;
 use warnings;
@@ -48,7 +50,7 @@ Log::ger::Output::File - Send logs to file
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -81,6 +83,8 @@ Alternatively, you can provide an already opened filehandle.
 
 L<Log::ger>
 
+L<Log::ger::Output::FileWriteRotate>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
